@@ -95,6 +95,32 @@ def refresh():
 				base_mon_hp_start[i] + temp_width,
 				base_mon_hp_y_start[i]+5)
 
+	#refresh the player hp bar
+	canvas_mon_pic.itemconfig(canvas_mon_pic.find_withtag("player_hp"),
+		text=str(player.hp) + "/" + str(player.adj_maxhp))
+
+	temp_width = base_mon_hp_width[0]*int(player.hp) / \
+											int(player.adj_maxhp)
+	if temp_width < 0: temp_width=0
+	canvas_mon_pic.coords(canvas_mon_pic.find_withtag("player_hp_bar"),
+			(background_pic.width()-base_mon_hp_width[0])/2,
+			background_pic.height()-hero_pic.height()*3/2-2,
+			(background_pic.width()-base_mon_hp_width[0])/2+temp_width,
+			background_pic.height()-hero_pic.height()*3/2+3,)
+
+	#refresh the player ep bar
+	canvas_mon_pic.itemconfig(canvas_mon_pic.find_withtag("player_ep"),
+		text=str(player.ep) + "/" + str(player.adj_maxep))
+
+	temp_width = base_mon_hp_width[0]*int(player.ep) / \
+											int(player.adj_maxep)
+	if temp_width < 0: temp_width=0
+	canvas_mon_pic.coords(canvas_mon_pic.find_withtag("player_ep_bar"),
+			(background_pic.width()-base_mon_hp_width[0])/2,
+			background_pic.height()-hero_pic.height(),
+			(background_pic.width()-base_mon_hp_width[0])/2+temp_width,
+			background_pic.height()-hero_pic.height()+5)
+
 	#Draw the monster selection arrow if needed.
 	canvas_mon_pic.delete(canvas_mon_pic.find_withtag("monster_arrow"))
 	global active_button
@@ -390,6 +416,7 @@ def can_leave():
 #run/leave/quit button was pressed
 def runaway():
 	global run_attempts
+	global did_run
 	clear_slashes()
 	try:
 		#leave/quit
@@ -402,7 +429,6 @@ def runaway():
 				window_battle.destroy()
 				main.print_message("You coward! You ran away from the "
 					+ monster.monster_groups[mon_index].name + ".")
-				global did_run
 				did_run = 1
 			else:
 				run_attempts += 1
@@ -551,7 +577,7 @@ def useskill():
 		#pay for the skill
 		player.give_stat("ep", -1*player.skill[skill_index][2])
 		mon_num = select_monster()
-		for i in range(3 + int(player.level)/3):
+		for i in range(2 + int(player.level)/4):
 			if monster_list[mon_num].hp < 1:
 				mon_num = select_monster()
 			if mon_num == -1: return 0
@@ -567,7 +593,7 @@ def useskill():
 		player.give_stat("ep", -1*player.skill[skill_index][2])
 		mon_num = select_monster()
 		if mon_num == -1: return 0
-		damage = (player.adj_attack * 5)/2
+		damage = (player.adj_attack)
 		monster_hurt(mon_num, damage)
 		if can_leave() == 0:
 			attack_player()
@@ -954,6 +980,7 @@ def begin(mon_index_input):
 	pic_frame.grid(row=1, column=2, columnspan=3, rowspan=6, sticky=E)
 
 	global canvas_mon_pic
+	global background_pic
 	background_pic = g.maps[g.zgrid].battle_background
 	canvas_mon_pic = Canvas(pic_frame,
 		height=background_pic.height(),
@@ -999,14 +1026,46 @@ def begin(mon_index_input):
 				base_mon_hp_y_start[i]+5, fill="#05BB05",
 				tags="monster_hp_rect"+ str(i))
 		canvas_mon_pic.create_text(xstart,
-			base_mon_hp_y_start[i]+7, anchor=N, text="", tags="mon_hp"+str(i))
+			base_mon_hp_y_start[i]+6, anchor=N, text="", tags="mon_hp"+str(i))
 
+	global hero_pic
 	try: hero_pic = g.tiles["people/hero_n" + g.maps[g.zgrid].hero_suffix + ".png"]
 	except KeyError: hero_pic = ImageTk.PhotoImage("RGB", (32, 32))
 	canvas_mon_pic.create_image(
 				background_pic.width()/2,
-				background_pic.height()-hero_pic.height()-5,
+				background_pic.height()-hero_pic.height()*5/2,
 				anchor=N, image=hero_pic, tags="hero")
+	#Under (red) part of the player hp display
+	canvas_mon_pic.create_rectangle(
+		(background_pic.width()-base_mon_hp_width[0])/2,
+		background_pic.height()-hero_pic.height()*3/2-2,
+		(background_pic.width()+base_mon_hp_width[0])/2,
+		background_pic.height()-hero_pic.height()*3/2+3, fill="#EE0505")
+	#Over (green) part of the player hp display
+	canvas_mon_pic.create_rectangle(
+		(background_pic.width()-base_mon_hp_width[0])/2,
+		background_pic.height()-hero_pic.height()*3/2-2,
+		(background_pic.width()+base_mon_hp_width[0])/2,
+		background_pic.height()-hero_pic.height()*3/2+3, fill="#05BB05",
+		tags="player_hp_bar")
+	canvas_mon_pic.create_text(background_pic.width()/2,
+		background_pic.height()-hero_pic.height()*3/2+4, anchor=N, text="", tags="player_hp")
+
+	#Under (red) part of the player ep display
+	canvas_mon_pic.create_rectangle(
+		(background_pic.width()-base_mon_hp_width[0])/2,
+		background_pic.height()-hero_pic.height(),
+		(background_pic.width()+base_mon_hp_width[0])/2,
+		background_pic.height()-hero_pic.height()+5, fill="#EE0505")
+	#Over (green) part of the player ep display
+	canvas_mon_pic.create_rectangle(
+		(background_pic.width()-base_mon_hp_width[0])/2,
+		background_pic.height()-hero_pic.height(),
+		(background_pic.width()+base_mon_hp_width[0])/2,
+		background_pic.height()-hero_pic.height()+5, fill="#0505EE",
+		tags="player_ep_bar")
+	canvas_mon_pic.create_text(background_pic.width()/2,
+		background_pic.height()-hero_pic.height()+6, anchor=N, text="", tags="player_ep")
 
 
 	#formatting for the labels.
@@ -1085,6 +1144,7 @@ def begin(mon_index_input):
 
 	#keep the window_main window asleep until this one is closed.
 	window_battle.master.wait_window(window_battle)
+	if player.hp <= 0: did_run = "end"
 	return did_run
 
 
@@ -1107,6 +1167,9 @@ def bind_keys():
 	listbox_skill.bind("<ButtonRelease-1>", mouse_handler_skill)
 	canvas_mon_pic.bind("<ButtonRelease-1>", attack)
 	canvas_mon_pic.bind("<Motion>", monster_mouse_move)
+	main.canvas_map.unbind("<Motion>")
+	main.canvas_map.unbind("<Button-1>")
+
 
 #keybindings when choosing a monster to attack.
 def bind_attack_keys():
