@@ -27,6 +27,9 @@ class item_class:
 	def __init__(self):
 		self.name = ""
 		#type is 0-5 for equipment, 10-20 for items, and 99 for system items.
+		#type 10 is unusable (use for story items/keys) 11 is healing, 12 is
+		#explosive, 14 is gems, 15-17 is scripted (15=usable in battle,
+		#16=usable out of battle, 17=usable in both).
 		self.type = 0
 		#The power of the item.
 		self.quality = 0
@@ -40,21 +43,16 @@ class item_class:
 		self.ep_bonus = 0
 		self.attack_bonus = 0
 		self.defense_bonus = 0
+		#An array of lines, describing the scripting run when the item is used.
+		self.scripting = []
 
-#equipment:
-#equip[0]=weapon, [1]=armor, [2]=shield
-#[3]=helmet, [4]=gloves, [5]=boots
-
-#Contains a number, which is either the index of the
-#item in the item[] array, or -1 for empty. Same deal for inv[].
-equip = []
-for x in range(6):
-	equip.append(x)
 
 #inventory: 28 spaces.
+#An array of numbers, which are either the index of the
+#item in the item[] array, or -1 for empty.
 inv = []
 for x in range(28):
-	inv.append(x)
+	inv.append(-1)
 
 #takes the index in the item[] array, and returns the index
 #of the first occurance in the inv[] array, or -1 for failure.
@@ -139,16 +137,19 @@ def additem(item_filename):
 	item[item_array_loc].name = ""
 	item[item_array_loc].type = 0
 	item[item_array_loc].quality = 0
-	item[item_array_loc].price = 0
-	item[item_array_loc].value = 0
+	item[item_array_loc].price = -1
+	item[item_array_loc].value = -1
 	item[item_array_loc].description = ""
 	item[item_array_loc].picturename = None
+	item[item_array_loc].scripting = []
 
 	item_file = g.read_script_file("/data/items/" + item_filename)
 
 	#go through all lines of the file
-	for item_line in item_file:
+	cur_line = 0
+	while cur_line < len(item_file):
 		#strip out spaces/tabs
+		item_line = item_file[cur_line]
 		item_line = item_line.strip()
 
 		#determine the command entered.
@@ -176,9 +177,21 @@ def additem(item_filename):
 			item[item_array_loc].attack_bonus = int(item_line.split("=", 1)[1])
 		elif (item_command.lower() == "defense_bonus"):
 			item[item_array_loc].defense_bonus = int(item_line.split("=", 1)[1])
-
-	if (item[item_array_loc].value == 0):
+		elif (item_command.lower() == ":scripting"):
+			cur_line += 1
+			while cur_line < len(item_file):
+				item_line = item_file[cur_line]
+				item_line = item_line.strip()
+				if item_line.lower() == ":values":
+					break
+				item[item_array_loc].scripting.append(item_line)
+				cur_line += 1
+		cur_line += 1
+	if (item[item_array_loc].value == -1):
 		item[item_array_loc].value = item[item_array_loc].price
+	if (item[item_array_loc].price == -1):
+		item[item_array_loc].price = item[item_array_loc].value
+
 
 #An array of dropped items. Used for keeping dropped items around
 #through save/loads.
