@@ -50,11 +50,11 @@ def cancel():
 def quit():
 	window_sel_game.destroy()
 
-def init_window():
+def init_window(mod_directory):
 	global window_sel_game
 	window_sel_game = Toplevel()
 
-	array_mods = listdir("../modules/Dragon Hunt/data/maps/")
+	array_mods = listdir(mod_directory + "/data/maps/")
 	#remove CVS directory
 	i = 0
 	while i < len(array_mods):
