@@ -66,16 +66,36 @@ def refresh_save_info(event=0):
 	save_loc = g.mod_directory + "/saves/" + save_title
 	savefile=open(save_loc, 'r')
 	version_unused = g.pickle.load(savefile)
-	name_text.set(g.pickle.load(savefile))
-	hp_text.set(g.pickle.load(savefile))
-	ep_text.set(g.pickle.load(savefile))
+	name_text = str(g.pickle.load(savefile))
+	hp_text = str(g.pickle.load(savefile))
+	ep_text = str(g.pickle.load(savefile))
 	unused_maxhp = g.pickle.load(savefile)
 	unused_maxep = g.pickle.load(savefile)
-	attack_text.set(g.pickle.load(savefile))
-	defense_text.set(g.pickle.load(savefile))
-	gold_text.set(g.pickle.load(savefile))
-	exp_text.set(g.pickle.load(savefile))
-	level_text.set(g.pickle.load(savefile))
+	attack_text = str(g.pickle.load(savefile))
+	defense_text = str(g.pickle.load(savefile))
+	gold_text = str(g.pickle.load(savefile))
+	exp_text = str(g.pickle.load(savefile))
+	level_text = str(g.pickle.load(savefile))
+
+	pixels_per_line = 20
+	canvas_info.delete(ALL)
+	canvas_info.create_text(5, 5+pixels_per_line*0,
+		text="Name: " + name_text, anchor=W)
+	canvas_info.create_text(5, 5+pixels_per_line*1,
+		text="HP: " + hp_text, anchor=W)
+	canvas_info.create_text(5, 5+pixels_per_line*2,
+		text="EP: " + ep_text, anchor=W)
+	canvas_info.create_text(5, 5+pixels_per_line*3,
+		text="Attack: " + attack_text, anchor=W)
+	canvas_info.create_text(5, 5+pixels_per_line*4,
+		text="Defense: " + defense_text, anchor=W)
+	canvas_info.create_text(5, 5+pixels_per_line*5,
+		text="Gold: " + gold_text, anchor=W)
+	canvas_info.create_text(5, 5+pixels_per_line*6,
+		text="Exp: " + exp_text, anchor=W)
+	canvas_info.create_text(5, 5+pixels_per_line*7,
+		text="Level: " + level_text, anchor=W)
+
 	savefile.close()
 
 
@@ -171,42 +191,50 @@ def init_window_loadgame():
 	scroll_saves.grid(row=1, column=5, rowspan=10, sticky="NSE")
 	listbox_saves.config(yscrollcommand=scroll_saves.set)
 
-	label_formatting = Label(window_loadgame, text="Name:")
-	label_formatting.grid(row=1, column=6, sticky=E)
-	label_formatting = Label(window_loadgame, text="hp:")
-	label_formatting.grid(row=2, column=6, sticky=E)
-	label_formatting = Label(window_loadgame, text="ep:")
-	label_formatting.grid(row=3, column=6, sticky=E)
-	label_formatting = Label(window_loadgame, text="attack:")
-	label_formatting.grid(row=4, column=6, sticky=E)
-	label_formatting = Label(window_loadgame, text="defense:")
-	label_formatting.grid(row=5, column=6, sticky=E)
-	label_formatting = Label(window_loadgame, text="gold:")
-	label_formatting.grid(row=6, column=6, sticky=E)
-	label_formatting = Label(window_loadgame, text="exp:")
-	label_formatting.grid(row=7, column=6, sticky=E)
-	label_formatting = Label(window_loadgame, text="level:")
-	label_formatting.grid(row=8, column=6, sticky=E)
+# 	label_formatting = Label(window_loadgame, text="Name:")
+# 	label_formatting.grid(row=1, column=6, sticky=E)
+# 	label_formatting = Label(window_loadgame, text="hp:")
+# 	label_formatting.grid(row=2, column=6, sticky=E)
+# 	label_formatting = Label(window_loadgame, text="ep:")
+# 	label_formatting.grid(row=3, column=6, sticky=E)
+# 	label_formatting = Label(window_loadgame, text="attack:")
+# 	label_formatting.grid(row=4, column=6, sticky=E)
+# 	label_formatting = Label(window_loadgame, text="defense:")
+# 	label_formatting.grid(row=5, column=6, sticky=E)
+# 	label_formatting = Label(window_loadgame, text="gold:")
+# 	label_formatting.grid(row=6, column=6, sticky=E)
+# 	label_formatting = Label(window_loadgame, text="exp:")
+# 	label_formatting.grid(row=7, column=6, sticky=E)
+# 	label_formatting = Label(window_loadgame, text="level:")
+# 	label_formatting.grid(row=8, column=6, sticky=E)
+#
+# 	label_name = Label(window_loadgame, textvar=name_text)
+# 	label_name.grid(row=1, column=7, sticky=W)
+# 	label_hp = Label(window_loadgame, textvar=hp_text)
+# 	label_hp.grid(row=2, column=7, sticky=W)
+# 	label_ep = Label(window_loadgame, textvar=ep_text)
+# 	label_ep.grid(row=3, column=7, sticky=W)
+# 	label_attack = Label(window_loadgame, textvar=attack_text)
+# 	label_attack.grid(row=4, column=7, sticky=W)
+# 	label_defense = Label(window_loadgame, textvar=defense_text)
+# 	label_defense.grid(row=5, column=7, sticky=W)
+# 	label_gold= Label(window_loadgame, textvar=gold_text)
+# 	label_gold.grid(row=6, column=7, sticky=W)
+# 	label_exp = Label(window_loadgame, textvar=exp_text)
+# 	label_exp.grid(row=7, column=7, sticky=W)
+# 	label_level = Label(window_loadgame, textvar=level_text)
+# 	label_level.grid(row=8, column=7, sticky=W)
+#
+# 	label_formatting = Label(window_loadgame, text="                    ")
+# 	label_formatting.grid(row=0, column=7, sticky=E)
+	window_loadgame.update_idletasks()
 
-	label_name = Label(window_loadgame, textvar=name_text)
-	label_name.grid(row=1, column=7, sticky=W)
-	label_hp = Label(window_loadgame, textvar=hp_text)
-	label_hp.grid(row=2, column=7, sticky=W)
-	label_ep = Label(window_loadgame, textvar=ep_text)
-	label_ep.grid(row=3, column=7, sticky=W)
-	label_attack = Label(window_loadgame, textvar=attack_text)
-	label_attack.grid(row=4, column=7, sticky=W)
-	label_defense = Label(window_loadgame, textvar=defense_text)
-	label_defense.grid(row=5, column=7, sticky=W)
-	label_gold= Label(window_loadgame, textvar=gold_text)
-	label_gold.grid(row=6, column=7, sticky=W)
-	label_exp = Label(window_loadgame, textvar=exp_text)
-	label_exp.grid(row=7, column=7, sticky=W)
-	label_level = Label(window_loadgame, textvar=level_text)
-	label_level.grid(row=8, column=7, sticky=W)
+	global canvas_info
+	canvas_info = Canvas(window_loadgame, width=listbox_saves.winfo_width(),
+		height=listbox_saves.winfo_height(),
+		highlightthickness=0)
+	canvas_info.grid(column=7, row=1, rowspan=8, sticky=N+W)
 
-	label_formatting = Label(window_loadgame, text="                    ")
-	label_formatting.grid(row=0, column=7, sticky=E)
 
 	global label_help
 	label_help = Label(window_loadgame, textvariable=help_text)
