@@ -41,7 +41,7 @@ from player import *
 
 #size, in tiles, of the main screen. While this is adjustable,
 #odd numbers would work much better. (To keep the player centered.)
-mapsizex = 19
+mapsizex = 23
 mapsizey = 13
 
 sidebarsize = 5
@@ -77,6 +77,8 @@ gold = StringVar()
 exp = StringVar()
 level = StringVar()
 
+#Image used for the inventory icon.
+inv_icon_image = "inv.png"
 
 #Print a message in status box. Works with ~Action~ embedded commands.
 def print_message(message):
@@ -116,12 +118,12 @@ def close_window(event=0):
 				window_main.destroy()
 			except TclError:
 				pass
-	elif (g.cur_window == "inventory"): #if called from inventory window
-		if player.hp < 1 or inv.inv_show_yesno("Leave this game?"):
-			try:
-				window_main.destroy()
-			except TclError:
-				pass
+# 	elif (g.cur_window == "inventory"): #if called from inventory window
+# 		if player.hp < 1 or inv.inv_show_yesno("Leave this game?"):
+# 			try:
+# 				window_main.destroy()
+# 			except TclError:
+# 				pass
 	elif canvas_map.winfo_exists():
 		if player.hp < 1 or show_yesno("Leave this game?"):
 			try:
@@ -145,9 +147,11 @@ def activate_scripting(x, y, z):
 	itemnum = 0
 	while itemnum < len(g.maps[g.zgrid].field[y][x].items):
 		itemname = g.maps[g.zgrid].field[y][x].items[itemnum]
-		if action.run_command(x, y, z, "find (\"" + itemname + "\", \"a\")"):
+		if action.run_command(x, y, z, "find(\"" + itemname + "\", \"a\")"):
 			g.maps[g.zgrid].del_item(itemname, x, y)
 			refresh_tile(x, y)
+			refresh_inv_icon()
+			refresh_bars()
 		else: itemnum += 1
 
 	#if there are no actions, leave immediately
@@ -166,8 +170,36 @@ def refreshmap():
 			refresh_tile(g.xgrid - half_mapx + x, g.ygrid - half_mapy + y)
 
 	refreshhero()
+	refresh_inv_icon()
+	refresh_bars()
 	recalc_stats()
 
+#refreshes the inventory icon in the upper-left.
+def refresh_inv_icon():
+	canvas_map.delete("inv_icon")
+	canvas_map.create_image(0, 0, image=g.buttons[inv_icon_image], anchor=NW,
+				tags="inv_icon")
+
+def refresh_bars():
+	canvas_map.delete("point_bars")
+	canvas_map.create_rectangle(0, g.buttons[inv_icon_image].height(),
+		g.buttons[inv_icon_image].width(), g.buttons[inv_icon_image].height()+5,
+				fill="#EE0505", tags="point_bars")
+	hpbar_width=g.buttons[inv_icon_image].width()*player.hp/player.adj_maxhp
+	canvas_map.create_rectangle(0, g.buttons[inv_icon_image].height(),
+		hpbar_width, g.buttons[inv_icon_image].height()+5,
+				fill="#05BB05", tags="point_bars")
+
+	canvas_map.create_rectangle(0, g.buttons[inv_icon_image].height()+6,
+		g.buttons[inv_icon_image].width(), g.buttons[inv_icon_image].height()+11,
+				fill="#EE0505", tags="point_bars")
+	epbar_width=g.buttons[inv_icon_image].width()*player.ep/player.adj_maxep
+
+	canvas_map.create_rectangle(0, g.buttons[inv_icon_image].height()+6,
+		epbar_width, g.buttons[inv_icon_image].height()+11,
+				fill="#0505EE", tags="point_bars")
+
+
 #given x and y (absolute coods.) refresh the given tile.
 def refresh_tile(x, y):
 	search_for = str(x)+"."+str(y)
@@ -182,7 +214,9 @@ def refreshhero():
 	canvas_map.delete("hero")
 	canvas_map.create_image(mapsizex*g.tilesize/2, mapsizey*g.tilesize/2,
 		image=g.tiles[player.cur_hero], tags="hero")
-
+	for picture in g.maps[g.zgrid].field[g.ygrid][g.xgrid].addoverpix:
+		canvas_map.create_image(mapsizex*g.tilesize/2, mapsizey*g.tilesize/2,
+					image=picture, tags="hero")
 
 #called to process the onload portion of a level. Called whenever entering
 #a level. Set g.zgrid properly before calling.
@@ -195,27 +229,27 @@ def process_onload():
 
 #re-display stats.
 def recalc_stats():
-	name.set(player.name)
-	attack.set(player.adj_attack)
-	defense.set(player.adj_defense)
-	gold.set(player.gold)
-	exp.set(player.exp)
-	level.set(player.level)
+# 	name.set(player.name)
+# 	attack.set(player.adj_attack)
+# 	defense.set(player.adj_defense)
+# 	gold.set(player.gold)
+# 	exp.set(player.exp)
+# 	level.set(player.level)
 
 	#hp/ep bars
-	canvas_hp.delete("show_hp")
-	temp_width = g.hpbar_width*player.hp/player.adj_maxhp
-	if temp_width < 0: temp_width=0
-	canvas_hp.create_rectangle(0, 0, temp_width,
-		g.hpbar_width/6, fill="#05BB05", tags="show_hp")
-	canvas_ep.delete("show_ep")
-	temp_width = g.hpbar_width*player.ep/player.adj_maxep
-	if temp_width < 0: temp_width=0
-	canvas_ep.create_rectangle(0, 0, temp_width,
-		g.hpbar_width/6, fill="#0505EE", tags="show_ep")
-	hp.set(str(player.hp) + "/" + str(player.adj_maxhp))
-	ep.set(str(player.ep) + "/" + str(player.adj_maxep))
-
+# 	canvas_hp.delete("show_hp")
+# 	temp_width = g.hpbar_width*player.hp/player.adj_maxhp
+# 	if temp_width < 0: temp_width=0
+# 	canvas_hp.create_rectangle(0, 0, temp_width,
+# 		g.hpbar_width/6, fill="#05BB05", tags="show_hp")
+# 	canvas_ep.delete("show_ep")
+# 	temp_width = g.hpbar_width*player.ep/player.adj_maxep
+# 	if temp_width < 0: temp_width=0
+# 	canvas_ep.create_rectangle(0, 0, temp_width,
+# 		g.hpbar_width/6, fill="#0505EE", tags="show_ep")
+# 	hp.set(str(player.hp) + "/" + str(player.adj_maxhp))
+# 	ep.set(str(player.ep) + "/" + str(player.adj_maxep))
+	refresh_bars()
 
 #Return an array of pictures that the given tile should display.
 #x and y are absolute coords.
@@ -232,6 +266,8 @@ def findtile(x, y):
 		returnpix.append(g.maps[g.zgrid].field[y][x].pix)
 		for picture in g.maps[g.zgrid].field[y][x].addpix:
 			returnpix.append(picture)
+		for picture in g.maps[g.zgrid].field[y][x].addoverpix:
+			returnpix.append(picture)
 		for itemname in g.maps[g.zgrid].field[y][x].items:
 			returnpix.append(
 				g.tiles[g.item.item[g.item.finditem(itemname)].picturename])
@@ -269,10 +305,16 @@ def move_hero(x, y):
 				g.xgrid=g.xgrid + x
 				g.ygrid=g.ygrid + y
 				passturn()
-				if y == -1: player.cur_hero = "people/hero_n" + g.maps[g.zgrid].hero_suffix + ".png"
-				if y ==  1: player.cur_hero = "people/hero_s" + g.maps[g.zgrid].hero_suffix + ".png"
-				if x == -1: player.cur_hero = "people/hero_w" + g.maps[g.zgrid].hero_suffix + ".png"
-				if x ==  1: player.cur_hero = "people/hero_e" + g.maps[g.zgrid].hero_suffix + ".png"
+				if g.allow_change_hero == 1:
+					if y == -1: player.cur_hero = "people/hero_n" + \
+							g.maps[g.zgrid].hero_suffix + ".png"
+					if y ==  1: player.cur_hero = "people/hero_s" + \
+							g.maps[g.zgrid].hero_suffix + ".png"
+					if x == -1: player.cur_hero = "people/hero_w" + \
+							g.maps[g.zgrid].hero_suffix + ".png"
+					if x ==  1: player.cur_hero = "people/hero_e" + \
+							g.maps[g.zgrid].hero_suffix + ".png"
+				g.allow_change_hero = 1
 				#Sometimes, quick refresh is bad.
 				global already_refreshed
 				if already_refreshed == 1:
@@ -301,13 +343,17 @@ def move_hero(x, y):
 				if x ==  1:
 					for tilenum in range(mapsizey):
 						refresh_tile(g.xgrid+half_mapx, g.ygrid-half_mapy+tilenum)
+				refresh_inv_icon()
+				refresh_bars()
 
 		else:
-			if (tempx == g.xgrid + x) and (tempy == g.ygrid + y):
+			if (tempx == g.xgrid + x) and (tempy == g.ygrid + y) and \
+									(g.allow_change_hero == 1):
 				if y == -1: player.cur_hero = "people/hero_n" + g.maps[g.zgrid].hero_suffix + ".png"
 				if y ==  1: player.cur_hero = "people/hero_s" + g.maps[g.zgrid].hero_suffix + ".png"
 				if x == -1: player.cur_hero = "people/hero_w" + g.maps[g.zgrid].hero_suffix + ".png"
 				if x ==  1: player.cur_hero = "people/hero_e" + g.maps[g.zgrid].hero_suffix + ".png"
+			g.allow_change_hero = 1
 			refreshhero()
 			recalc_stats()
 		g.allow_move = 1
@@ -357,17 +403,21 @@ def passturn():
 def start_battle(mon_index):
 	global free_move
 #	right.destroy()
-	button_inv.config(state=DISABLED)
-	button_save.config(state=DISABLED)
-	if battle.begin(mon_index) == 1:  #if you ran, you failed
+#	button_inv.config(state=DISABLED)
+#	button_save.config(state=DISABLED)
+	tmp=battle.begin(mon_index)
+	if tmp == 1:  #if you ran, you failed
 		return_num = 0
-	else:
+	elif tmp == 0:
 		return_num = 1  #otherwise, you succeeded.
+	elif tmp == "end":
+		return_num = "end"
+		dead_yet()
 	#number of free moves after attack:
 	free_move = 4
 	g.cur_window = "main"
-	button_inv.config(state=NORMAL)
-	button_save.config(state=NORMAL)
+#	button_inv.config(state=NORMAL)
+#	button_save.config(state=NORMAL)
 	player.reset_stats()
 	refreshmap()
 	bind_keys()
@@ -377,6 +427,7 @@ def start_battle(mon_index):
 #Call to display a dialog box. Used to work with action.py.
 #Note this only works if window_main is visible.
 def show_dialog(line=None):
+	unbind_keys()
 	line = action.interpret_line(line)
 	if window_main.state() != "normal":
 		return 0
@@ -412,7 +463,6 @@ def show_dialog(line=None):
 		if window_main.state() != "normal": return 1
 	except TclError: return 1
 	bind_keys()
-	canvas_map.bind("<Button-1>", mouse_handler)
 	action.has_dialog = 0
 	canvas_map.delete("dialogtxt", "ok", "background_box")
 	return 1
@@ -447,6 +497,7 @@ def show_yesno(line=""):
 	canvas_map.create_image((mapsizex*tilesize/2),
 		(6*mapsizey*tilesize/7), image=g.buttons["yes.png"], anchor="nw", tags="yes")
 	#bindings
+	canvas_map.unbind("<Motion>")
 	window_main.bind(g.binding_up, change_yesno_sel)
 	window_main.bind(g.binding_right, change_yesno_sel)
 	window_main.bind(g.binding_left, change_yesno_sel)
@@ -463,7 +514,6 @@ def show_yesno(line=""):
 		if window_main.state() != "normal": return 1
 	except TclError: return 1
 	bind_keys()
-	canvas_map.bind("<Button-1>", mouse_handler)
 	action.has_dialog = 0
 	canvas_map.delete("dialogtxt", "no", "yes", "background_box")
 
@@ -536,6 +586,8 @@ def accept_console(event=None):
 def cleanup(event=None):
 	activate_yesno()
 	battle.return_from_dialog.set("2")
+	inv.leave_inv()
+	shop.leave_shop()
 	window_main.destroy()
 	action.has_dialog = 0
 
@@ -579,74 +631,74 @@ def init_window_main(new_game = 0):
 	name.set(player.name)
 
 	#left (stats) side frame
-	global left
-	left = Frame(top, bg=bgcolour);
-	left.grid(row=1, column=0, columnspan=sidebarsize, sticky=NW)
-
-	#formatting for the labels.
-	label_formatting = Label(left, text="Name:", bg=bgcolour).grid(row=5,
-		column=1, sticky=E)
-	label_formatting = Label(left, text="HP:", bg=bgcolour).grid(row=6,
-		column=1, sticky=E)
-	label_formatting = Label(left, text="EP:", bg=bgcolour).grid(row=8,
-		column=1, sticky=E)
-	label_formatting = Label(left, text="Attack:", bg=bgcolour).grid(row=10,
-		column=1, sticky=E)
-	label_formatting = Label(left, text="Defense:", bg=bgcolour).grid(row=11,
-		column=1, sticky=E)
-	label_formatting = Label(left, text="Gold:", bg=bgcolour).grid(row=12,
-		column=1, sticky=E)
-	label_formatting = Label(left, text="Exp:", bg=bgcolour).grid(row=13,
-		column=1, sticky=E)
-	label_formatting = Label(left, text="Level:", bg=bgcolour).grid(row=14,
-		column=1, sticky=E)
-
-	#display of stats
-	label_name = Label(left, textvariable=name, bg=bgcolour).grid(row=5,
-		column=2, sticky=W)
-
-	global canvas_hp
-	canvas_hp = Canvas(left, width=g.hpbar_width,
-		height=g.hpbar_width/6, highlightthickness=0)
-	canvas_hp.grid(column=1, row=7, columnspan=2, sticky=W, padx=5)
-	canvas_hp.create_rectangle(0, 0, g.hpbar_width,
-		g.hpbar_width/2, fill="#EE0505")
-	global canvas_ep
-	canvas_ep = Canvas(left, width=g.hpbar_width,
-		height=g.hpbar_width/6, highlightthickness=0)
-	canvas_ep.grid(column=1, row=9, columnspan=2, sticky=W, padx=5)
-	canvas_ep.create_rectangle(0, 0, g.hpbar_width,
-		g.hpbar_width/2, fill="#EE0505")
-
-	label_hp = Label(left, textvariable=hp, bg=bgcolour).grid(row=6,
-		column=2, sticky=W)
-	label_ep = Label(left, textvariable=ep, bg=bgcolour).grid(row=8,
-		column=2, sticky=W)
-	label_attack = Label(left, textvariable=attack, bg=bgcolour).grid(row=10,
-		column=2, sticky=W)
-	label_defense = Label(left, textvariable=defense, bg=bgcolour).grid(row=11,
-		column=2, sticky=W)
-	label_gold = Label(left, textvariable=gold, bg=bgcolour).grid(row=12,
-		column=2, sticky=W)
-	label_exp = Label(left, textvariable=exp, bg=bgcolour).grid(row=13,
-		column=2, sticky=W)
-	label_level = Label(left, textvariable=level, bg=bgcolour).grid(row=14,
-		column=2, sticky=W)
-
-
-	#inventory and movement buttons.
-	global button_inv #global because we need to disable it sometimes.
-	global button_save
-	global button_quit
-	button_inv = Button(left, text="Inventory", underline="0",
-		command=show_inv, bg=buttoncolour)
-	button_inv.grid(row=15, column=1, columnspan=2, sticky=EW)
-	button_save = Button(left, text="Save", underline="0",
-		command=save_game, bg=buttoncolour)
-	button_save.grid(row=16, column=1, columnspan=2, sticky=EW)
-	button_quit = Button(left, text="Quit", underline="0",
-		command=close_window, bg=buttoncolour)
-	button_quit.grid(row=17, column=1, columnspan=2, sticky=EW)
+# 	global left
+# 	left = Frame(top, bg=bgcolour);
+# 	left.grid(row=1, column=0, columnspan=sidebarsize, sticky=NW)
+#
+# 	#formatting for the labels.
+# 	label_formatting = Label(left, text="Name:", bg=bgcolour).grid(row=5,
+# 		column=1, sticky=E)
+# 	label_formatting = Label(left, text="HP:", bg=bgcolour).grid(row=6,
+# 		column=1, sticky=E)
+# 	label_formatting = Label(left, text="EP:", bg=bgcolour).grid(row=8,
+# 		column=1, sticky=E)
+# 	label_formatting = Label(left, text="Attack:", bg=bgcolour).grid(row=10,
+# 		column=1, sticky=E)
+# 	label_formatting = Label(left, text="Defense:", bg=bgcolour).grid(row=11,
+# 		column=1, sticky=E)
+# 	label_formatting = Label(left, text="Gold:", bg=bgcolour).grid(row=12,
+# 		column=1, sticky=E)
+# 	label_formatting = Label(left, text="Exp:", bg=bgcolour).grid(row=13,
+# 		column=1, sticky=E)
+# 	label_formatting = Label(left, text="Level:", bg=bgcolour).grid(row=14,
+# 		column=1, sticky=E)
+#
+# 	#display of stats
+# 	label_name = Label(left, textvariable=name, bg=bgcolour).grid(row=5,
+# 		column=2, sticky=W)
+#
+# 	global canvas_hp
+# 	canvas_hp = Canvas(left, width=g.hpbar_width,
+# 		height=g.hpbar_width/6, highlightthickness=0)
+# 	canvas_hp.grid(column=1, row=7, columnspan=2, sticky=W, padx=5)
+# 	canvas_hp.create_rectangle(0, 0, g.hpbar_width,
+# 		g.hpbar_width/2, fill="#EE0505")
+# 	global canvas_ep
+# 	canvas_ep = Canvas(left, width=g.hpbar_width,
+# 		height=g.hpbar_width/6, highlightthickness=0)
+# 	canvas_ep.grid(column=1, row=9, columnspan=2, sticky=W, padx=5)
+# 	canvas_ep.create_rectangle(0, 0, g.hpbar_width,
+# 		g.hpbar_width/2, fill="#EE0505")
+#
+# 	label_hp = Label(left, textvariable=hp, bg=bgcolour).grid(row=6,
+# 		column=2, sticky=W)
+# 	label_ep = Label(left, textvariable=ep, bg=bgcolour).grid(row=8,
+# 		column=2, sticky=W)
+# 	label_attack = Label(left, textvariable=attack, bg=bgcolour).grid(row=10,
+# 		column=2, sticky=W)
+# 	label_defense = Label(left, textvariable=defense, bg=bgcolour).grid(row=11,
+# 		column=2, sticky=W)
+# 	label_gold = Label(left, textvariable=gold, bg=bgcolour).grid(row=12,
+# 		column=2, sticky=W)
+# 	label_exp = Label(left, textvariable=exp, bg=bgcolour).grid(row=13,
+# 		column=2, sticky=W)
+# 	label_level = Label(left, textvariable=level, bg=bgcolour).grid(row=14,
+# 		column=2, sticky=W)
+#
+#
+# 	#inventory and movement buttons.
+# 	global button_inv #global because we need to disable it sometimes.
+# 	global button_save
+# 	global button_quit
+# 	button_inv = Button(left, text="Inventory", underline="0",
+# 		command=show_inv, bg=buttoncolour)
+# 	button_inv.grid(row=15, column=1, columnspan=2, sticky=EW)
+# 	button_save = Button(left, text="Save", underline="0",
+# 		command=save_game, bg=buttoncolour)
+# 	button_save.grid(row=16, column=1, columnspan=2, sticky=EW)
+# 	button_quit = Button(left, text="Quit", underline="0",
+# 		command=close_window, bg=buttoncolour)
+# 	button_quit.grid(row=17, column=1, columnspan=2, sticky=EW)
 	#this creates the actual map portion.
 	create_map()
 
@@ -690,14 +742,39 @@ def bind_keys():
 	window_main.bind(g.binding_down, move_south)
 	window_main.bind(g.binding_cancel, close_window)
 	window_main.bind(g.binding_inv, show_inv)
-	window_main.bind(g.binding_attack, do_nothing)
+	window_main.unbind(g.binding_attack)
 	window_main.bind(g.binding_save, save_game)
 	window_main.bind(g.binding_quit, close_window)
 	window_main.bind(g.binding_action, show_inv)
 	window_main.bind(g.binding_console, load_console)
+	canvas_map.bind("<Button-1>", mouse_handler)
+	canvas_map.unbind("<Double-Button-1>")
+	canvas_map.unbind("<ButtonRelease-1>")
+	canvas_map.bind("<Motion>", mouse_move)
+
+def unbind_keys():
+	window_main.unbind(g.binding_up)
+	window_main.unbind(g.binding_right)
+	window_main.unbind(g.binding_left)
+	window_main.unbind(g.binding_down)
+	window_main.unbind(g.binding_cancel)
+	window_main.unbind(g.binding_inv)
+	window_main.unbind(g.binding_attack)
+	window_main.unbind(g.binding_save)
+	window_main.unbind(g.binding_quit)
+	window_main.unbind(g.binding_action)
+	window_main.unbind(g.binding_console)
+	canvas_map.unbind("<Button-1>")
+	canvas_map.unbind("<Double-Button-1>")
+	canvas_map.unbind("<Motion>")
 
 #handles mouse clicks on the main tile canvas.
 def mouse_handler(event=0):
+	if event.x < g.buttons["inv.png"].width() and \
+					event.y < g.buttons["inv.png"].height():
+		show_inv()
+		return
+
 	#set variables, based on the shape of the main window. (tall or wide)
 	if mapsizex > mapsizey:
 		mapsz = mapsizey*g.tilesize
@@ -716,6 +793,18 @@ def mouse_handler(event=0):
 		if (event.x + event.y > mapstartx+mapstarty+mapsz): move_east()
 		else: move_north()
 
+#called whenever the mouse moves
+def mouse_move(event=0):
+	global inv_icon_image
+	if event.x < g.buttons["inv.png"].width() and \
+					event.y < g.buttons["inv.png"].height():
+		new_icon_image = "inv_sel.png"
+	else:
+		new_icon_image = "inv.png"
+	if new_icon_image != inv_icon_image:
+		inv_icon_image = new_icon_image
+		refresh_inv_icon()
+
 def create_map():
 	#right side frame contains map
 	global right
@@ -733,11 +822,13 @@ def show_inv(event=0):
 		if window_main.state() != "normal" or action.has_dialog == 1:
 			return
 #		right.destroy()
-		button_inv.config(state=DISABLED)
-		button_save.config(state=DISABLED)
+# 		button_inv.config(state=DISABLED)
+# 		button_save.config(state=DISABLED)
+# 		button_quit.config(state=DISABLED)
 		inv.init_window_inv()
-		button_inv.config(state=NORMAL)
-		button_save.config(state=NORMAL)
+# 		button_inv.config(state=NORMAL)
+# 		button_save.config(state=NORMAL)
+# 		button_quit.config(state=NORMAL)
 #		create_map()
 		refreshmap()
 		recalc_stats()
@@ -747,13 +838,14 @@ def show_inv(event=0):
 
 def enter_store(cur_loc):
 #	right.destroy()
-	button_inv.config(state=DISABLED)
-	button_save.config(state=DISABLED)
-	button_quit.config(state=DISABLED)
+# 	button_inv.config(state=DISABLED)
+# 	button_save.config(state=DISABLED)
+# 	button_quit.config(state=DISABLED)
+	unbind_keys()
 	shop.init_window_shop(cur_loc)
-	button_inv.config(state=NORMAL)
-	button_save.config(state=NORMAL)
-	button_quit.config(state=NORMAL)
+# 	button_inv.config(state=NORMAL)
+# 	button_save.config(state=NORMAL)
+# 	button_quit.config(state=NORMAL)
 #	create_map()
 	refreshmap()
 	recalc_stats()
