@@ -79,28 +79,28 @@ def create_map():
 	cur_map.field.append([])
 	for y in range(mapsize_x): #upper border
 		cur_map.field[0].append(g.tile(""))
-		cur_map.field[0][len(cur_map.field[0])-1].onload.append("pix " + border)
-		cur_map.field[0][len(cur_map.field[0])-1].onload.append("walk 0")
+		cur_map.field[0][len(cur_map.field[0])-1].onload.append("pix(\""+border+"\")")
+		cur_map.field[0][len(cur_map.field[0])-1].onload.append("walk(0)")
 
 	for x in range(mapsize_y-2):
 		cur_map.field.append([])
 		cur_map.field[x+1].append(g.tile("")) #left border
-		cur_map.field[x+1][0].onload.append("pix " + border)
-		cur_map.field[x+1][0].onload.append("walk 0")
+		cur_map.field[x+1][0].onload.append("pix(\""+border+"\")")
+		cur_map.field[x+1][0].onload.append("walk(0)")
 		for y in range(mapsize_x - 2):
 			cur_map.field[x+1].append(g.tile("")) #inside
-			cur_map.field[x+1][len(cur_map.field[x+1])-1].onload.append("pix " + background)
-			cur_map.field[x+1][len(cur_map.field[x+1])-1].onload.append("walk 1")
+			cur_map.field[x+1][len(cur_map.field[x+1])-1].onload.append("pix(\""+background+"\")")
+			cur_map.field[x+1][len(cur_map.field[x+1])-1].onload.append("walk(1)")
 		cur_map.field[x+1].append(g.tile("")) #right border
-		cur_map.field[x+1][len(cur_map.field[x+1])-1].onload.append("pix " + border)
-		cur_map.field[x+1][len(cur_map.field[x+1])-1].onload.append("walk 0")
+		cur_map.field[x+1][len(cur_map.field[x+1])-1].onload.append("pix(\""+border+"\")")
+		cur_map.field[x+1][len(cur_map.field[x+1])-1].onload.append("walk(0)")
 
 	cur_map.field.append([])
 	map_len = len(cur_map.field)-1
 	for y in range(mapsize_x):
 		cur_map.field[map_len].append(g.tile("")) #lower border
-		cur_map.field[map_len][len(cur_map.field[map_len])-1].onload.append("pix " + border)
-		cur_map.field[map_len][len(cur_map.field[map_len])-1].onload.append("walk 0")
+		cur_map.field[map_len][len(cur_map.field[map_len])-1].onload.append("pix(\""+border+"\")")
+		cur_map.field[map_len][len(cur_map.field[map_len])-1].onload.append("walk(0)")
 
 	global canvas_map
 	canvas_map = Canvas(top, width=g.tilesize*portalsize,
@@ -170,8 +170,8 @@ def set_bkg(bkg):
 	for y in range(mapsize_y-2):
 		for x in range(mapsize_x - 2):
 			cur_map.field[y+1][x+1].onload = []
-			cur_map.field[y+1][x+1].onload.append("pix " + bkg)
-			cur_map.field[y+1][x+1].onload.append("walk 1")
+			cur_map.field[y+1][x+1].onload.append("pix(\""+bkg+"\")")
+			cur_map.field[y+1][x+1].onload.append("walk(1)")
 	refresh_map()
 
 #what will appear around edges of map (must be walk 0 to keep hero penned in)
@@ -180,20 +180,20 @@ def set_border(edge):
 	border = edge
 	for y in range(mapsize_y):
 		cur_map.field[y][0].onload = []
-		cur_map.field[y][0].onload.append("pix " + edge)
-		cur_map.field[y][0].onload.append("walk 0")
+		cur_map.field[y][0].onload.append("pix(\""+edge+"\")")
+		cur_map.field[y][0].onload.append("walk(0)")
 		temp_len = len(cur_map.field[y])-1
 		cur_map.field[y][temp_len].onload = []
-		cur_map.field[y][temp_len].onload.append("pix " + edge)
-		cur_map.field[y][temp_len].onload.append("walk 0")
+		cur_map.field[y][temp_len].onload.append("pix(\""+edge+"\")")
+		cur_map.field[y][temp_len].onload.append("walk(0)")
 	for x in range(mapsize_x):
 		cur_map.field[0][x].onload = []
-		cur_map.field[0][x].onload.append("pix " + edge)
-		cur_map.field[0][x].onload.append("walk 0")
+		cur_map.field[0][x].onload.append("pix(\""+edge+"\")")
+		cur_map.field[0][x].onload.append("walk(0)")
 		temp_len = len(cur_map.field)-1
 		cur_map.field[temp_len][x].onload = []
-		cur_map.field[temp_len][x].onload.append("pix " + edge)
-		cur_map.field[temp_len][x].onload.append("walk 0")
+		cur_map.field[temp_len][x].onload.append("pix(\""+edge+"\")")
+		cur_map.field[temp_len][x].onload.append("walk(0)")
 
 	refresh_map()
 
@@ -206,16 +206,19 @@ def refresh_map():
 		for x in range(portal_x, portal_x+portalsize):
 			if x >= mapsize_x: break
 			for line in cur_map.field[y][x].onload:
-				if line.strip().split()[0].strip().lower() == "pix" or \
-				line.strip().split()[0].strip().lower() == "addpix":
+				line=line.strip()
+				if line == "": continue
+				if line[:3].lower() == "pix" or line[:6].lower() == "addpix":
 					canvas_map.create_image((x-portal_x)*g.tilesize,
 						(y-portal_y)*g.tilesize, anchor=NW,
-						image=g.tiles[line.strip().split(None, 1)[1].strip()])
-				elif len(line.strip().split()) >= 8 and \
-				line.strip().split()[6].strip().lower() == "addpix":
-					canvas_map.create_image((x-portal_x)*g.tilesize,
-						(y-portal_y)*g.tilesize, anchor=NW,
-						image=g.tiles[line.strip().split()[7].strip()])
+						image=g.tiles[line[line.find("(")+2:g.action.match_command(line)-2]])
+
+	#I think (hope) the following section is useless.
+	# 				elif len(line.strip().split()) >= 8 and \
+	# 				line.strip().split()[6].strip().lower() == "addpix":
+	# 					canvas_map.create_image((x-portal_x)*g.tilesize,
+	# 						(y-portal_y)*g.tilesize, anchor=NW,
+	# 						image=g.tiles[line.strip().split()[7].strip()])
 	#If we are adjusting walkable status, display black/white box on tile.
 	#White for walkable, Black for non. Note that if the walkable status
 	#depends on an if statement, this may have incorrect results. (No good
@@ -226,21 +229,51 @@ def refresh_map():
 			for x in range(portal_x, portal_x+portalsize):
 				if x >= mapsize_x: break
 				for line in cur_map.field[y][x].onload:
-					if line.strip().lower() == "walk 1":
+					line=line.strip().lower()
+					if line == "walk(1)":
 						canvas_map.create_rectangle(
 							(x-portal_x)*g.tilesize + g.tilesize/3,
 							(y-portal_y)*g.tilesize + g.tilesize/3,
 							(x-portal_x)*g.tilesize + 2*g.tilesize/3,
 							(y-portal_y)*g.tilesize + 2*g.tilesize/3,
 							fill="white")
-					if line.strip().lower() == "walk 0":
+					if line == "walk(0)":
 						canvas_map.create_rectangle(
 							(x-portal_x)*g.tilesize + g.tilesize/3,
 							(y-portal_y)*g.tilesize + g.tilesize/3,
 							(x-portal_x)*g.tilesize + 2*g.tilesize/3,
 							(y-portal_y)*g.tilesize + 2*g.tilesize/3,
-							fill="black")
-	#If the tiles has some scripting, display a black-bordered white square.
+							fill="black", outline="white")
+					#The wall_* display. Show a black bar on the given side.
+					if line == "wall_n(1)":
+						canvas_map.create_rectangle(
+							(x-portal_x)*g.tilesize + g.tilesize/8,
+							(y-portal_y)*g.tilesize + 2,
+							(x-portal_x)*g.tilesize + 7*g.tilesize/8,
+							(y-portal_y)*g.tilesize + 5,
+							fill="black", outline="white")
+					if line == "wall_s(1)":
+						canvas_map.create_rectangle(
+							(x-portal_x)*g.tilesize + g.tilesize/8,
+							(y-portal_y)*g.tilesize + g.tilesize-2,
+							(x-portal_x)*g.tilesize + 7*g.tilesize/8,
+							(y-portal_y)*g.tilesize + g.tilesize-5,
+							fill="black", outline="white")
+					if line == "wall_w(1)":
+						canvas_map.create_rectangle(
+							(x-portal_x)*g.tilesize + 2,
+							(y-portal_y)*g.tilesize + g.tilesize/8,
+							(x-portal_x)*g.tilesize + 5,
+							(y-portal_y)*g.tilesize + 7*g.tilesize/8,
+							fill="black", outline="white")
+					if line == "wall_e(1)":
+						canvas_map.create_rectangle(
+							(x-portal_x)*g.tilesize + g.tilesize-2,
+							(y-portal_y)*g.tilesize + g.tilesize/8,
+							(x-portal_x)*g.tilesize + g.tilesize-5,
+							(y-portal_y)*g.tilesize + 7*g.tilesize/8,
+							fill="black", outline="white")
+	#If the tiles have some scripting, display a black-bordered white square.
 	#(To make sure it displays well on all tiles.)
 	#This ignores the pix and walk commands that all tiles must have.
 	if cur_mode == "scripting":
@@ -250,8 +283,8 @@ def refresh_map():
 				if x >= mapsize_x: break
 				draw_boxes = 0
 				for line in cur_map.field[y][x].onload:
-					temp_command = line.split()[0].strip().lower()
-					if temp_command != "walk" and temp_command != "pix":
+					temp_command = line.strip()[:3].lower()
+					if temp_command != "wal" and temp_command != "pix":
 						draw_boxes = 1
 				if len(cur_map.field[y][x].actions) > 0:
 					draw_boxes = 1
@@ -281,30 +314,30 @@ def set_tile(x, y, name):
 	if tile_prefix == "items" and cur_mode != "remove":
 		add_item(x, y, name)
 	elif cur_mode == "add":
-		cur_map.field[y][x].onload.append("addpix " + name);
+		cur_map.field[y][x].onload.append("addpix(\""+name+"\")");
 	elif cur_mode == "remove":
 		cur_map.field[y][x].onload = []
-		cur_map.field[y][x].onload.append("pix " + background)
-		cur_map.field[y][x].onload.append("walk 1")
+		cur_map.field[y][x].onload.append("pix(\""+background+"\")")
+		cur_map.field[y][x].onload.append("walk(1)")
 	elif cur_mode == "walkable":
 		for line_num in range(len(cur_map.field[y][x].onload)):
-			if cur_map.field[y][x].onload[line_num] == "walk 1":
-				cur_map.field[y][x].onload[line_num] = "walk 0"
-			elif cur_map.field[y][x].onload[line_num] == "walk 0":
-				cur_map.field[y][x].onload[line_num] = "walk 1"
+			if cur_map.field[y][x].onload[line_num] == "walk(1)":
+				cur_map.field[y][x].onload[line_num] = "walk(0)"
+			elif cur_map.field[y][x].onload[line_num] == "walk(0)":
+				cur_map.field[y][x].onload[line_num] = "walk(1)"
 	elif cur_mode == "scripting":
 		change_scripting(x, y)
 	else:
 		temp_name = name
 		for line_num in range(len(cur_map.field[y][x].onload)):
-			if cur_map.field[y][x].onload[line_num].split()[0].strip().lower() == "pix":
-				cur_map.field[y][x].onload[line_num] = "pix " + name
+			if cur_map.field[y][x].onload[line_num][:3].strip().lower() == "pix":
+				cur_map.field[y][x].onload[line_num] = "pix(\""+name+"\")"
 				temp_name = name
 		for line_num in range(len(cur_map.field[y][x].onload)):
-			if cur_map.field[y][x].onload[line_num].split()[0].strip().lower() == "walk":
-				try: cur_map.field[y][x].onload[line_num] = "walk " + walk[temp_name]
+			if cur_map.field[y][x].onload[line_num][:4].strip().lower() == "walk":
+				try: cur_map.field[y][x].onload[line_num] = "walk("+walk[temp_name]+")"
 				#default to walkable.
-				except KeyError: cur_map.field[y][x].onload[line_num] = "walk 1"
+				except KeyError: cur_map.field[y][x].onload[line_num] = "walk(1)"
 	refresh_map()
 
 #add name item to tile at x, y
@@ -314,16 +347,16 @@ def add_item(x, y, name):
 	item_name = re.sub("_", " ", item)
 	var_name = item + "_" + map_name + "_" + str(item_list[name])
 	item_list[name] += 1
-	cur_map.field[y][x].onload.append("if var " + var_name + " = 0")
-	cur_map.field[y][x].onload.append("	addpix " + name)
+	cur_map.field[y][x].onload.append("if(var(\""+var_name+"\"), \"=\", 0)")
+	cur_map.field[y][x].onload.append("	addpix(\""+name+"\")")
 	cur_map.field[y][x].onload.append("endif")
 	global amount
 	amount = "AMOUNT"
 	set_item_amount()
-	cur_map.field[y][x].actions.append("if var " + var_name + " = 0")
-	cur_map.field[y][x].actions.append("	if find \""  + item_name + "\" " + amount)
-	cur_map.field[y][x].actions.append("		set " + var_name + " 1")
-	cur_map.field[y][x].actions.append("		delpix " + name)
+	cur_map.field[y][x].actions.append("if(var(\""+var_name+"\"), \"=\", 0)")
+	cur_map.field[y][x].actions.append("	if(find(\""+item_name+"\", \""+amount+"\"), \"=\", 1)")
+	cur_map.field[y][x].actions.append("		set(\""+var_name+"\", \"=\", 1)")
+	cur_map.field[y][x].actions.append("		delpix(\""+name+"\")")
 	cur_map.field[y][x].actions.append("	endif")
 	cur_map.field[y][x].actions.append("endif")
 
@@ -502,7 +535,7 @@ def get_walk_values():
 def set_codes():
 	global codes
 	codes = []
-	#This gives me a few thousand tiles per map.
+	#This gives me a few thousand (3844) distinct tiles per map.
 	for i in  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789":
 		for j in "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789":
 			codes.append(i + j)
@@ -616,14 +649,14 @@ def save_map(event=0):
 		map_file.write("hero_bg=" + cur_map.hero_suffix + "\n")
 
 
-	#use the upper-left tile as background.
-	map_file.write(":a\n")
-	for onload_line in cur_map.field[0][0].onload:
-		if onload_line.split()[0].strip().lower() == "pix":
-			map_file.write(onload_line + "\n")
-			break
-
-	map_file.write("walk 0" + "\n")
+# 	#use the upper-left tile as background.
+# 	map_file.write(":a\n")
+# 	for onload_line in cur_map.field[0][0].onload:
+# 		if onload_line.split()[0].strip().lower() == "pix":
+# 			map_file.write(onload_line + "\n")
+# 			break
+#
+# 	map_file.write("walk(0)" + "\n")
 	for tile_type in range(count): #for each tile type.
 		map_file.write(":" + codes[tile_type] + "\n")
 		for y in range(mapsize_y): #Find an example of that tile.
@@ -643,7 +676,7 @@ def save_map(event=0):
 
 #loads the loadmap window, then loads the returned map into cur_map.
 def do_load_map():
-	if (load_map.init_window() == 0): return
+	if (load_map.init_window(g.mod_directory) == 0): return
 	g.zgrid = g.mapname2zgrid(load_map.mapname)
 	global cur_map
 	cur_map = g.map("")
@@ -790,8 +823,8 @@ def really_change_mapsize(x, y):
 		elif len(cur_map.field[tmpy]) < int(x):
 			for tmpx in range(int(x) - len(cur_map.field[tmpy])):
 				cur_map.field[tmpy].append(g.tile(""))
-				cur_map.field[tmpy][len(cur_map.field[tmpy])-1].onload.append("pix " + background)
-				cur_map.field[tmpy][len(cur_map.field[tmpy])-1].onload.append("walk 0")
+				cur_map.field[tmpy][len(cur_map.field[tmpy])-1].onload.append("pix(\"" + background+"\")")
+				cur_map.field[tmpy][len(cur_map.field[tmpy])-1].onload.append("walk(0)")
 
 	global portal_x
 	global portal_y
@@ -876,6 +909,8 @@ def make_menus():
 	background_menu.add_command(label='dirt', command=(lambda x="underground/dirt.png":set_bkg(x)))
 	background_menu.add_command(label='void', command=(lambda x="underground/void.png":set_bkg(x)))
 	background_menu.add_command(label='grass', command=(lambda x="grass.png":set_bkg(x)))
+	background_menu.add_command(label='desert', command=(lambda x="desert/desert_grass.png":set_bkg(x)))
+
 
 	#border submenu
 	border_menu = Menu(map_options, bg=bgcolour)
