@@ -65,6 +65,8 @@ def init_window():
 	while i < len(array_mods):
 		if array_mods[i] == "CVS":
 			array_mods.pop(i)
+		elif array_mods[i] == "default":
+			array_mods.pop(i)
 		else:
 			i += 1
 
@@ -80,7 +82,6 @@ def init_window():
 	window_sel_game.maxsize(900, 900)
 	window_sel_game.wm_geometry("+%d+%d" % (20, 20))
 
-	g.init_tk_already = 1
 	global listbox_mods
 	listbox_mods = Listbox(window_sel_game, height=10)
 	listbox_mods.grid(row=1, column=1, rowspan=10, sticky=N+W+E)
