@@ -46,6 +46,9 @@ class tile:
 		self.actions = []
 		#An array of Tkinter image references, that show extra tiles.
 		self.addpix = []
+		#An array of Tkinter image references, that show extra tiles for
+		#over-hero graphics
+		self.addoverpix = []
 		#An array of item names; the items that exist on this tile.
 		self.items = []
 	def add_act(self, action):
@@ -54,8 +57,12 @@ class tile:
 		self.onload.append(onload)
 	def add_pix(self, picture):
 		self.addpix.append(picture)
+	def add_over_pix(self, picture):
+		self.addoverpix.append(picture)
 	def del_pix(self, picture):
 		self.addpix.remove(picture)
+	def del_over_pix(self, picture):
+		self.addoverpix.remove(picture)
 	def additem(self, itemname):
 		self.items.append(itemname)
 #		self.addpix.append(
