@@ -69,75 +69,83 @@ curr_skill = StringVar()
 global store_name
 store_name = StringVar()
 
+temp_canvas_width=0
+temp_canvas_height=0
+canvas_x_start = 0
+canvas_y_start = 0
+
+
+temp_button_x = 0
+temp_button_width = 0
+temp_button_y = 0
+
+
+back_to_main = StringVar()
+
 #refresh the button canvas
 def refresh_buttons(event=0):
-	canvas_buttons.delete(ALL)
-	if (cur_button == 0): canvas_buttons.create_image(0, 0, anchor=NW,
-						image=g.buttons["sell_sel.png"])
-	else: canvas_buttons.create_image(sell_height, 0, anchor=NW,
-						image=g.buttons["sell.png"])
 
-	if (cur_button == 1): canvas_buttons.create_image(leave_height, 0,
-			anchor=NW, image=g.buttons["leave_shop_sel.png"])
-	else: canvas_buttons.create_image(leave_height, 0, anchor=NW,
-						image=g.buttons["leave_shop.png"])
+	main.canvas_map.delete("shop_buttons")
+	main.canvas_map.create_rectangle(temp_button_x, temp_button_y,
+				temp_button_x+temp_button_width,
+				temp_button_y+g.buttons["sell.png"].height(), fill=bgcolour,
+				tags=("shop_buttons", "shop"))
+	if (cur_button == 0): main.canvas_map.create_image(
+						temp_button_x, temp_button_y, anchor=NW,
+						image=g.buttons["sell_sel.png"],
+						tags=("shop_buttons", "shop"))
+	else: main.canvas_map.create_image(temp_button_x, temp_button_y, anchor=NW,
+						image=g.buttons["sell.png"],
+						tags=("shop_buttons", "shop"))
 
-	if (cur_button == 2): canvas_buttons.create_image(buy_height, 0, anchor=NW,
-						image=g.buttons["buy_sel.png"])
-	else: canvas_buttons.create_image(buy_height, 0, anchor=NW,
-						image=g.buttons["buy.png"])
+	if (cur_button == 1): main.canvas_map.create_image(
+						temp_button_x+leave_height, temp_button_y,
+						anchor=NW, image=g.buttons["leave_shop_sel.png"],
+						tags=("shop_buttons", "shop"))
+	else: main.canvas_map.create_image(temp_button_x+leave_height,
+						temp_button_y, anchor=NW,
+						image=g.buttons["leave_shop.png"],
+						tags=("shop_buttons", "shop"))
+
+	if (cur_button == 2): main.canvas_map.create_image(
+						temp_button_x+buy_height, temp_button_y, anchor=NW,
+						image=g.buttons["buy_sel.png"],
+						tags=("shop_buttons", "shop"))
+	else: main.canvas_map.create_image(temp_button_x+buy_height,
+						temp_button_y, anchor=NW,
+						image=g.buttons["buy.png"],
+						tags=("shop_buttons", "shop"))
 
 
 #refresh the inventory canvas
-def refresh_inv():
-	canvas_inv.delete("item")
-	invpos = 0
-	#if the inv is selected, draw a selection box around the current item.
-	if curr_focus == 0:
-		canvas_inv.create_rectangle(
-				(curr_item%shop_width)*g.tilesize +
-							2 * ((curr_item%shop_width)+1),
-				(curr_item/shop_width)*g.tilesize +
-							2 * ((curr_item/shop_width)+1),
-				((curr_item%shop_width)+1)*(g.tilesize + 2),
-				((curr_item/shop_width)+1)*(g.tilesize + 2),
-							fill=g.fill_sel_colour, tags="item")
-
-	#draw the item pictures.
-	for i in range(len(item.inv)):
-		if item.inv[i] != -1:
-			canvas_inv.create_image((i%shop_width)*g.tilesize + 2 *
-												((i%shop_width)+1),
-				(i/shop_width)*g.tilesize + 2 * ((i/shop_width)+1),
-				image=g.tiles[item.item[item.inv[i]].picturename],
-				anchor="nw", tags="item")
-			invpos += 1
-
-	#set gold and skillpoints
-	curr_gold.set("Gold: " + str(player.gold))
-	curr_skill.set("Skillpoints: " + str(player.skillpoints))
-	main.recalc_stats()
+# def refresh_inv():
+# 	canvas_inv.delete("inv")
 
 #Actually sets the info in the middle of the shop screen.
 def set_details(name, cost, value, costtype, power, description, inv_or_shop):
-	item_name.set(name)
+	main.canvas_map.delete("shop_details")
+
+	main.canvas_map.create_text(canvas_x_start+temp_canvas_width+5,
+		canvas_y_start+25, anchor=W, text=name, tags=("shop_details", "shop"))
+
 	if inv_or_shop == "shop":
 		if cost != "":
-			item_cost.set("Cost: " + str(cost) + " " + costtype)
-			#item_value.set("")
-			#global label_cost
-			#label_cost.lift()
-		else: item_cost.set("")
+				main.canvas_map.create_text(canvas_x_start+temp_canvas_width+5,
+				canvas_y_start+40, anchor=W, text="Cost: "+str(cost),
+				tags=("shop_details", "shop"))
 	elif inv_or_shop == "inv":
-	   	if value != "":
-			item_cost.set("Value: " + str(value) + " " + costtype)
-			#item_cost.set("")
-		else: item_cost.set("")
-	if power == "" or power == "-1": item_power.set("")
-	else: item_power.set("Power: " + str(power))
-	canvas_desc.delete("all")
-	canvas_desc.create_text(1, 5, anchor=NW,
-		text=description, width=142)
+		if value != "":
+			main.canvas_map.create_text(canvas_x_start+temp_canvas_width+5,
+			canvas_y_start+40, anchor=W, text="Value: "+str(value),
+			tags=("shop_details", "shop"))
+	if power == "" or power == "-1": pass
+	else: main.canvas_map.create_text(canvas_x_start+temp_canvas_width+5,
+		canvas_y_start+55, anchor=W, text="Power: "+str(power),
+		tags=("shop_details", "shop"))
+
+	main.canvas_map.create_text(canvas_x_start+temp_canvas_width+5,
+		canvas_y_start+70, anchor=NW, width=130, text=description,
+		tags=("shop_details", "shop"))
 
 #show info for a selected item in the middle of the window.
 def show_details(event=0, sel_item=-1):
@@ -168,28 +176,61 @@ def show_details(event=0, sel_item=-1):
 
 #place appropriate items into the store.
 def refresh_shop():
-	canvas_shop.delete("item")
+	main.canvas_map.delete("item")
 	invpos = 0
 	#if the shop is selected, draw a selection box around the current item.
 	if curr_focus == 1:
-		canvas_shop.create_rectangle(
-				(curr_item%shop_width)*g.tilesize + 2 *
+		main.canvas_map.create_rectangle(
+			canvas_x_start+temp_canvas_width*2+(curr_item%shop_width)*g.tilesize + 2 *
 												((curr_item%shop_width)+1),
-				(curr_item/shop_width)*g.tilesize + 2 *
+			canvas_y_start+(curr_item/shop_width)*g.tilesize + 2 *
 												((curr_item/shop_width)+1),
-				((curr_item%shop_width)+1)*(g.tilesize + 2),
-				((curr_item/shop_width)+1)*(g.tilesize + 2),
-												fill=g.fill_sel_colour, tags="item")
+			canvas_x_start+temp_canvas_width*2+((curr_item%shop_width)+1)*(g.tilesize + 2),
+			canvas_y_start+((curr_item/shop_width)+1)*(g.tilesize + 2),
+											fill=g.fill_sel_colour, tags=("item", "shop"))
 
 	#draw the item pictures.
 	for i in range(len(g.shops[store_num].itemlist)):
 		if i != -1:
-			canvas_shop.create_image((invpos%shop_width)*g.tilesize + 2 *
+			main.canvas_map.create_image(
+				canvas_x_start+temp_canvas_width*2+(invpos%shop_width)*g.tilesize + 2 *
 													((invpos%shop_width)+1),
-				(invpos/shop_width)*g.tilesize + 2 * ((invpos/shop_width)+1),
+				canvas_y_start+(invpos/shop_width)*g.tilesize + 2 * ((invpos/shop_width)+1),
 				image=g.tiles[g.shops[store_num].itemlist[i].picture],
-				anchor="nw", tags="item")
+				anchor="nw", tags=("item", "shop"))
 			invpos += 1
+	invpos = 0
+	#if the inv is selected, draw a selection box around the current item.
+	if curr_focus == 0:
+		main.canvas_map.create_rectangle(
+				canvas_x_start+(curr_item%shop_width)*g.tilesize +
+							2 * ((curr_item%shop_width)+1),
+				canvas_y_start+(curr_item/shop_width)*g.tilesize +
+							2 * ((curr_item/shop_width)+1),
+				canvas_x_start+((curr_item%shop_width)+1)*(g.tilesize + 2),
+				canvas_y_start+((curr_item/shop_width)+1)*(g.tilesize + 2),
+							fill=g.fill_sel_colour, tags=("item", "shop"))
+
+	#draw the item pictures.
+	for i in range(len(item.inv)):
+		if item.inv[i] != -1:
+			main.canvas_map.create_image(canvas_x_start+(i%shop_width)*g.tilesize + 2 *
+												((i%shop_width)+1),
+				canvas_y_start+(i/shop_width)*g.tilesize + 2 * ((i/shop_width)+1),
+				image=g.tiles[item.item[item.inv[i]].picturename],
+				anchor="nw", tags=("item", "shop"))
+			invpos += 1
+
+	#set gold and skillpoints
+	main.canvas_map.create_text(canvas_x_start+temp_canvas_width+5,
+		canvas_y_start+temp_canvas_height-20, anchor=SW,
+		text="Gold: "+str(player.gold), tags=("item", "shop"))
+	main.canvas_map.create_text(canvas_x_start+temp_canvas_width+5,
+		canvas_y_start+temp_canvas_height-2, anchor=SW,
+		text="Skillpoints: "+str(player.skillpoints), tags=("item", "shop"))
+#	curr_gold.set("Gold: " + str(player.gold))
+#	curr_skill.set("Skillpoints: " + str(player.skillpoints))
+	main.recalc_stats()
 
 #called upon pressing "Sell". Uses the selected item.
 def sell_item():
@@ -209,7 +250,7 @@ def sell_item():
 	#full value anywhere but the gem shop
 	#print g.shops[store_num].name
 	if (item.item[item.inv[curr_item]].type == 14 and
-		        g.shops[store_num].name == "a Gem Shop"):
+				g.shops[store_num].name == "a Gem Shop"):
 		main.print_message("The Gem Shop owner is happy to pay the true value of your gems.")
 		player.give_stat("gold", item.item[item.inv[curr_item]].price)
 	else:
@@ -220,7 +261,7 @@ def sell_item():
 
 	#remove the item
 	item.drop_inv_item(curr_item)
-	refresh_inv()
+	#refresh_inv()
 	refresh_shop()
 	show_details()
 
@@ -272,7 +313,7 @@ def buy_item():
 					player.give_stat("skillpoints", -1*
 							int(g.shops[store_num].itemlist[curr_item].cost))
 
-	refresh_inv()
+	#refresh_inv()
 	refresh_shop()
 	show_details()
 
@@ -291,6 +332,9 @@ def which_box(x, y):
 	tempy = tempy - (likelyy * (g.tilesize + 2))
 	if tempy >= g.tilesize - 1: return -1
 
+	if likelyx >= shop_width: return -1
+	if likelyy * shop_width + likelyx >= shop_width * shop_height: return -1
+
 	return likelyy * shop_width + likelyx
 
 #called when the user releases the mouse in the inv canvas.
@@ -302,41 +346,96 @@ def mouse_sel_inv(event=0):
 	if temp_num == -1: return
 	curr_item = temp_num
 	curr_focus = 0
-	refresh_inv()
+	#refresh_inv()
 	refresh_shop()
 	show_details()
 
 #called when the user releases the mouse in the shop canvas.
 def mouse_sel_shop(event=0):
-	#decide if the mouse is within one of the boxes.
 	global curr_item
 	global curr_focus
-	temp_num =  which_box(event.x, event.y)
-	if temp_num == -1: return
-	curr_item = temp_num
-	curr_focus = 1
-	refresh_inv()
-	refresh_shop()
-	show_details()
+	global cur_button
+	#Is the mouse at least in the general area?.
+	if event.x < canvas_x_start or event.y < canvas_y_start:
+		return 0
 
+	temp_num = which_box(event.x-canvas_x_start, event.y-canvas_y_start)
+	if temp_num != -1:
+		curr_item = temp_num
+		curr_focus = 0
+		cur_button = 0
+		refresh_shop()
+		show_details()
+		return 0
+
+	temp_num = which_box(event.x-canvas_x_start-temp_canvas_width*2,
+											event.y-canvas_y_start)
+	if temp_num != -1:
+		curr_item = temp_num
+		curr_focus = 1
+		cur_button = 2
+		refresh_shop()
+		show_details()
+		return 0
+
+	if (event.x > temp_button_x and event.x < temp_button_x + temp_button_width
+			and event.y > temp_button_y and
+			event.y < temp_button_y + g.buttons["buy.png"].height()):
+		if (event.x < temp_button_x + leave_height):
+			sell_item()
+		elif (event.x < temp_button_x + buy_height):
+			leave_shop()
+			return 0
+		else: buy_item()
+		refresh_buttons()
 
 def leave_shop(event=0):
 	try:
-		window_shop.destroy()
+		back_to_main.set(1)
 	except TclError:
 		pass
 
-def mouse_handler_click(event=0):
-	key_handler("return")
+def mouse_handler_dbl(event=0):
+	global curr_item
+	global curr_focus
+	global cur_button
+	#Is the mouse at least in the general area?.
+	if event.x < canvas_x_start or event.y < canvas_y_start:
+		return 0
+
+	temp_num = which_box(event.x-canvas_x_start, event.y-canvas_y_start)
+	if temp_num != -1:
+		curr_item = temp_num
+		curr_focus = 0
+		cur_button = 0
+		sell_item()
+		refresh_shop()
+		show_details()
+		return 0
+
+	temp_num = which_box(event.x-canvas_x_start-temp_canvas_width*2,
+											event.y-canvas_y_start)
+	if temp_num != -1:
+		curr_item = temp_num
+		curr_focus = 1
+		cur_button = 2
+		buy_item()
+		refresh_shop()
+		show_details()
+		return 0
+
 
 def mouse_handler_move(event=0):
-        global cur_button
-        if (event.x < leave_height):
-                cur_button = 0
-        elif (event.x < buy_height):
-                cur_button = 1
-        else: cur_button = 2
-        refresh_buttons()
+	global cur_button
+	if (event.x > temp_button_x and event.x < temp_button_x + temp_button_width
+			and event.y > temp_button_y and
+			event.y < temp_button_y + g.buttons["buy.png"].height()):
+		if (event.x < temp_button_x + leave_height):
+			cur_button = 0
+		elif (event.x < temp_button_x + buy_height):
+			cur_button = 1
+		else: cur_button = 2
+		refresh_buttons()
 
 #All keypresses in window_shop pass through here. Based on the key name,
 #give the right action. ("etc", "left", "right", "up", "down", "return")
@@ -352,8 +451,8 @@ def key_handler(switch):
 		if(curr_focus == 1 and cur_button == 2): buy_item()
 		elif(curr_focus !=1 and cur_button == 0): sell_item()
 		elif(cur_button == 1):
-		    leave_shop()
-		    return
+			leave_shop()
+			return
 	elif (switch == "left"):
 		if (curr_item % shop_width == 0):  #move between lists
 			if curr_focus == 0:
@@ -383,7 +482,7 @@ def key_handler(switch):
 		if curr_item >= shop_width * shop_height:
 			curr_item -= shop_width * shop_height
 
-	refresh_inv()
+	#refresh_inv()
 	refresh_shop()
 	refresh_buttons()
 	show_details()
@@ -400,11 +499,28 @@ def key_handler_return(event=0): key_handler("return")
 
 #create window_shop
 def init_window_shop(store_type_input):
-	global window_shop
+	global temp_canvas_width; global temp_canvas_height
+	global canvas_x_start; global canvas_y_start
+	global temp_button_x; global temp_button_width; global temp_button_y
+	temp_canvas_width=(g.tilesize*shop_width)+ ((shop_width+1)*2) + 1
+	temp_canvas_height=(g.tilesize*shop_height)+ ((shop_height+1)*2) + 1
+	canvas_x_start = ((g.tilesize*main.mapsizex)-temp_canvas_width * 3)/2
+	canvas_y_start = ((g.tilesize*main.mapsizey)-temp_canvas_height)/2
+	temp_button_x = canvas_x_start + (temp_canvas_width*3)/2- \
+			g.buttons["sell.png"].width()-g.buttons["leave_shop.png"].width()/2
+	temp_button_width = g.buttons["sell.png"].width()+ \
+			g.buttons["leave_shop.png"].width() + g.buttons["buy.png"].width()
+	temp_button_y = canvas_y_start + temp_canvas_height+1
+
+	main.canvas_map.delete("shop")
+#	global window_shop
 	global bgcolour
 	bgcolour = "lightgrey"
-	window_shop = Frame(main.top, bd=4, relief=GROOVE, bg=bgcolour)
-	window_shop.grid(row=1, column=5, columnspan=13, sticky=E)
+#	window_shop = Frame(main.top, bd=4, relief=GROOVE, bg=bgcolour)
+#	window_shop.grid(row=1, column=5, columnspan=13, sticky=E)
+	main.canvas_map.create_rectangle(canvas_x_start-2,canvas_y_start-19,
+		temp_canvas_width*2+canvas_x_start+temp_canvas_width+1,
+		canvas_y_start+temp_canvas_height+1, fill=bgcolour, tags="shop")
 
 	global curr_item
 	curr_item = 0
@@ -421,73 +537,81 @@ def init_window_shop(store_type_input):
 			break
 
 	#Inventory canvas
-	temp_canvas_width=(g.tilesize*shop_width)+ ((shop_width+1)*2) + 1
-	temp_canvas_height=(g.tilesize*shop_height)+ ((shop_height+1)*2) + 1
 	global canvas_inv
-	canvas_inv = Canvas(window_shop, width=temp_canvas_width,
-		height=temp_canvas_height, highlightthickness=0, bg=g.outline_colour)
-	canvas_inv.grid(column=1, row=2, columnspan=2, rowspan=16)
+	#canvas_inv = Canvas(window_shop, width=temp_canvas_width,
+	#	height=temp_canvas_height, highlightthickness=0, bg=g.outline_colour)
+	#canvas_inv.grid(column=1, row=2, columnspan=2, rowspan=16)
 	#outside border
-	canvas_inv.create_rectangle(0,0, temp_canvas_width-1, temp_canvas_height-1)
+	main.canvas_map.create_rectangle(canvas_x_start,canvas_y_start,
+		canvas_x_start+temp_canvas_width-1,
+		canvas_y_start+temp_canvas_height-1, tags="shop")
 	#per-item borders
 	for y in range(shop_height):
 		for x in range(shop_width):
-			canvas_inv.create_rectangle(x*g.tilesize + 2 * (x+1),
-										y*g.tilesize + 2 * (y+1),
-										(x+1)*(g.tilesize + 2),
-										(y+1)*(g.tilesize + 2), fill=g.fill_colour)
+			main.canvas_map.create_rectangle(canvas_x_start+x*g.tilesize + 2 * (x+1),
+										canvas_y_start+y*g.tilesize + 2 * (y+1),
+										canvas_x_start+(x+1)*(g.tilesize + 2),
+										canvas_y_start+(y+1)*(g.tilesize + 2),
+										fill=g.fill_colour, tags="shop")
 
 	#Shop canvas
-	global canvas_shop
-	canvas_shop = Canvas(window_shop, width=temp_canvas_width,
-		height=temp_canvas_height, highlightthickness=0, bg=g.outline_colour)
-	canvas_shop.grid(column=6, row=2, columnspan=2, rowspan=16)
+	#global canvas_shop
+	#canvas_shop = Canvas(window_shop, width=temp_canvas_width,
+	#	height=temp_canvas_height, highlightthickness=0, bg=g.outline_colour)
+	#canvas_shop.grid(column=6, row=2, columnspan=2, rowspan=16)
 	#outside border
-	canvas_shop.create_rectangle(0,0, temp_canvas_width-1, temp_canvas_height-1)
+	main.canvas_map.create_rectangle(temp_canvas_width*2+canvas_x_start,canvas_y_start,
+		temp_canvas_width*2+canvas_x_start+temp_canvas_width-1,
+		canvas_y_start+temp_canvas_height-1, tags="shop")
 	#per-item borders
 	for y in range(shop_height):
 		for x in range(shop_width):
-			canvas_shop.create_rectangle(x*g.tilesize + 2 * (x+1),
-										y*g.tilesize + 2 * (y+1),
-										(x+1)*(g.tilesize + 2),
-										(y+1)*(g.tilesize + 2), fill=g.fill_colour)
+			main.canvas_map.create_rectangle(
+				temp_canvas_width*2+canvas_x_start+x*g.tilesize + 2 * (x+1),
+				canvas_y_start+y*g.tilesize + 2 * (y+1),
+				temp_canvas_width*2+canvas_x_start+(x+1)*(g.tilesize + 2),
+				canvas_y_start+(y+1)*(g.tilesize + 2), fill=g.fill_colour, tags="shop")
 
 	#Info labels
-        global store_name
-        store_name.set(g.shops[store_num].name)
-        label_inv = Label(window_shop, text="Inventory",
-                bg=bgcolour).grid(row=1, column=2, sticky=W)
-        label_shop = Label(window_shop, textvar=store_name,
-                bg=bgcolour).grid(row=1, column=6, sticky=E)
-	label_name = Label(window_shop, textvar=item_name,
-		wraplength=143, bg=bgcolour).grid(row=8, column=3, sticky=NW)
-	global label_cost
-	label_cost = Label(window_shop,
-		textvar=item_cost, bg=bgcolour)
-	label_cost.grid(row=9, column=3, sticky=W)
+# 	global store_name
+# 	store_name.set(g.shops[store_num].name)
+# 	label_inv = Label(window_shop, text="Inventory",
+# 		bg=bgcolour).grid(row=1, column=2, sticky=W)
+	main.canvas_map.create_text(canvas_x_start+(temp_canvas_width*1)/2,
+		 canvas_y_start-1, anchor=S, text="Inventory", tags="shop")
+	main.canvas_map.create_text(canvas_x_start+(temp_canvas_width*5)/2,
+		 canvas_y_start-1, anchor=S, text=g.shops[store_num].name, tags="shop")
+# 	label_shop = Label(window_shop, textvar=store_name,
+# 		bg=bgcolour).grid(row=1, column=6, sticky=E)
+# 	label_name = Label(window_shop, textvar=item_name,
+# 		wraplength=143, bg=bgcolour).grid(row=8, column=3, sticky=NW)
+# 	global label_cost
+# 	label_cost = Label(window_shop,
+# 		textvar=item_cost, bg=bgcolour)
+# 	label_cost.grid(row=9, column=3, sticky=W)
 # 	label_value = Label(window_shop,
 # 		textvar=item_value, bg=bgcolour).grid(row=9, column=3, sticky=W)
-	label_power = Label(window_shop,
-		textvar=item_power, bg=bgcolour).grid(row=11, column=3, sticky=W)
+# 	label_power = Label(window_shop,
+# 		textvar=item_power, bg=bgcolour).grid(row=11, column=3, sticky=W)
 
-	global canvas_desc
-	canvas_desc = Canvas(window_shop, width=143, highlightthickness=0,
-			bg=bgcolour)
-	canvas_desc.grid(row=12, column=3, rowspan=8, sticky=NSEW)
+# 	global canvas_desc
+# 	canvas_desc = Canvas(window_shop, width=143, highlightthickness=0,
+# 			bg=bgcolour)
+# 	canvas_desc.grid(row=12, column=3, rowspan=8, sticky=NSEW)
 
-	label_skill = Label(window_shop, textvar=curr_skill, anchor=SW,
-		bg=bgcolour).grid(row=18, column=3, sticky=SW)
-	label_gold = Label(window_shop, textvar=curr_gold, anchor=NW,
-		bg=bgcolour).grid(row=19, column=3, sticky=W)
+# 	label_skill = Label(window_shop, textvar=curr_skill, anchor=SW,
+# 		bg=bgcolour).grid(row=18, column=3, sticky=SW)
+# 	label_gold = Label(window_shop, textvar=curr_gold, anchor=NW,
+# 		bg=bgcolour).grid(row=19, column=3, sticky=W)
 
 
 	global leave_height; leave_height = g.buttons["sell.png"].width()
 	global buy_height; buy_height = leave_height + g.buttons["leave.png"].width()
 
-	global canvas_buttons
-	canvas_buttons = Canvas(window_shop, height=g.buttons["buy.png"].height(),
-		width=buy_height+g.buttons["buy.png"].width(), bg=bgcolour)
-	canvas_buttons.grid(column=1, row=29, columnspan=8)
+# 	global canvas_buttons
+# 	canvas_buttons = Canvas(window_shop, height=g.buttons["buy.png"].height(),
+# 		width=buy_height+g.buttons["buy.png"].width(), bg=bgcolour)
+# 	canvas_buttons.grid(column=1, row=29, columnspan=8)
 
 
 #	global button_sell
@@ -502,13 +626,13 @@ def init_window_shop(store_type_input):
 #		command=leave_shop, bg=bgcolour).grid(row=28, column=3)
 
 	#get data in listboxes
-	refresh_inv()
+#	refresh_inv()
 	refresh_shop()
 	refresh_buttons()
 
 	#bindings
-	canvas_shop.bind("<ButtonRelease-1>", mouse_sel_shop)
-	canvas_inv.bind("<ButtonRelease-1>",  mouse_sel_inv)
+	main.canvas_map.bind("<ButtonRelease-1>", mouse_sel_shop)
+	main.canvas_map.bind("<Double-Button-1>",  mouse_handler_dbl)
 	main.window_main.bind(g.binding_cancel, key_handler_esc)
 	main.window_main.bind(g.binding_left, key_handler_left)
 	main.window_main.bind(g.binding_right, key_handler_right)
@@ -518,10 +642,12 @@ def init_window_shop(store_type_input):
 	main.window_main.bind(g.binding_inv, key_handler)
 	main.window_main.bind(g.binding_save, key_handler)
 	main.window_main.bind(g.binding_quit, key_handler)
-	canvas_buttons.bind("<ButtonRelease-1>", mouse_handler_click)
-        canvas_buttons.bind("<Motion>", mouse_handler_move)
+#	canvas_buttons.bind("<ButtonRelease-1>", mouse_handler_click)
+	main.canvas_map.bind("<Motion>", mouse_handler_move)
+#	main.canvas_map.unbind("<Motion>")
+	main.canvas_map.unbind("<Button-1>")
 
 	show_details()
-	window_shop.master.wait_window(window_shop)
-
+	main.window_main.wait_variable(back_to_main)
+	main.canvas_map.delete("shop")
 
